@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::Plugin::CheckExtraTests;
 # ABSTRACT: check xt tests before release
 
-our $VERSION = '0.027';
+our $VERSION = '0.028'; # from Dist-Zilla-Plugin-CheckExtraTests-0.028.tar.gz
 
 # Dependencies
 use Dist::Zilla 4.3 ();
@@ -102,7 +102,7 @@ Dist::Zilla::Plugin::CheckExtraTests - check xt tests before release
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 SYNOPSIS
 
@@ -174,7 +174,7 @@ Jesse Luehrs <doy@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Christopher J. Madsen David H. Adler Karen Etheridge Kent Fredric Olivier Mengue Ricardo Signes
+=for stopwords Christopher J. Madsen David H. Adler Karen Etheridge Kent Fredric Olivier Mengué Ricardo Signes
 
 =over 4
 
@@ -196,7 +196,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =item *
 
-Olivier Mengue <dolmen@cpan.org>
+Olivier Mengué <dolmen@cpan.org>
 
 =item *
 
